summaryrefslogtreecommitdiffstats
path: root/libktorrent/interfaces
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/interfaces')
-rw-r--r--libktorrent/interfaces/filetreediritem.cpp20
-rw-r--r--libktorrent/interfaces/filetreediritem.h8
-rw-r--r--libktorrent/interfaces/filetreeitem.cpp6
-rw-r--r--libktorrent/interfaces/filetreeitem.h4
-rw-r--r--libktorrent/interfaces/plugin.cpp4
-rw-r--r--libktorrent/interfaces/plugin.h2
-rw-r--r--libktorrent/interfaces/prefpageinterface.h4
7 files changed, 24 insertions, 24 deletions
diff --git a/libktorrent/interfaces/filetreediritem.cpp b/libktorrent/interfaces/filetreediritem.cpp
index 7cb78ca..86481f2 100644
--- a/libktorrent/interfaces/filetreediritem.cpp
+++ b/libktorrent/interfaces/filetreediritem.cpp
@@ -37,7 +37,7 @@ namespace kt
FileTreeDirItem::FileTreeDirItem(KListView* klv,const TQString & name,FileTreeRootListener* rl)
: TQCheckListItem(klv,TQString(),TQCheckListItem::CheckBox),name(name),root_listener(rl)
{
- tqparent = 0;
+ parent = 0;
size = 0;
setPixmap(0,KGlobal::iconLoader()->loadIcon("folder",KIcon::Small));
setText(0,name);
@@ -48,9 +48,9 @@ namespace kt
manual_change = false;
}
- FileTreeDirItem::FileTreeDirItem(FileTreeDirItem* tqparent,const TQString & name)
- : TQCheckListItem(tqparent,TQString(),TQCheckListItem::CheckBox),
- name(name),tqparent(tqparent)
+ FileTreeDirItem::FileTreeDirItem(FileTreeDirItem* parent,const TQString & name)
+ : TQCheckListItem(parent,TQString(),TQCheckListItem::CheckBox),
+ name(name),parent(parent)
{
size = 0;
setPixmap(0,KGlobal::iconLoader()->loadIcon("folder",KIcon::Small));
@@ -161,8 +161,8 @@ namespace kt
return;
}
}
- if (tqparent)
- tqparent->childStateChange();
+ if (parent)
+ parent->childStateChange();
}
setText(2,on ? i18n("Yes") : i18n("No"));
}
@@ -219,8 +219,8 @@ namespace kt
setOn(allChildrenOn());
manual_change = false;
- if (tqparent)
- tqparent->childStateChange();
+ if (parent)
+ parent->childStateChange();
else if (root_listener)
root_listener->treeItemChanged();
@@ -286,10 +286,10 @@ namespace kt
TQString FileTreeDirItem::getPath() const
{
- if (!tqparent)
+ if (!parent)
return bt::DirSeparator();
else
- return tqparent->getPath() + name + bt::DirSeparator();
+ return parent->getPath() + name + bt::DirSeparator();
}
}
diff --git a/libktorrent/interfaces/filetreediritem.h b/libktorrent/interfaces/filetreediritem.h
index 9afdbd1..37de320 100644
--- a/libktorrent/interfaces/filetreediritem.h
+++ b/libktorrent/interfaces/filetreediritem.h
@@ -51,12 +51,12 @@ namespace kt
Uint64 size;
bt::PtrMap<TQString,FileTreeItem> tqchildren;
bt::PtrMap<TQString,FileTreeDirItem> subdirs;
- FileTreeDirItem* tqparent;
+ FileTreeDirItem* parent;
bool manual_change;
FileTreeRootListener* root_listener;
public:
FileTreeDirItem(KListView* klv,const TQString & name,FileTreeRootListener* rl = 0);
- FileTreeDirItem(FileTreeDirItem* tqparent,const TQString & name);
+ FileTreeDirItem(FileTreeDirItem* parent,const TQString & name);
virtual ~FileTreeDirItem();
/// Get the path of the directory (if this is the root directory / will be returned)
@@ -93,11 +93,11 @@ namespace kt
void invertChecked();
/**
- * Called by the child to notify the tqparent it's state has changed.
+ * Called by the child to notify the parent it's state has changed.
*/
void childStateChange();
- FileTreeDirItem* getParent() {return tqparent;}
+ FileTreeDirItem* getParent() {return parent;}
/// Recusively get the total number of bytes to download
Uint64 bytesToDownload() const;
diff --git a/libktorrent/interfaces/filetreeitem.cpp b/libktorrent/interfaces/filetreeitem.cpp
index 666c1a0..6431152 100644
--- a/libktorrent/interfaces/filetreeitem.cpp
+++ b/libktorrent/interfaces/filetreeitem.cpp
@@ -35,7 +35,7 @@ namespace kt
FileTreeItem::FileTreeItem(FileTreeDirItem* item,const TQString & name,kt::TorrentFileInterface & file)
: TQCheckListItem(item,TQString(),TQCheckListItem::CheckBox),name(name),file(file)
{
- tqparent = item;
+ parent = item;
manual_change = false;
init();
}
@@ -66,7 +66,7 @@ namespace kt
}
updatePriorityText();
- tqparent->childStateChange();
+ parent->childStateChange();
}
void FileTreeItem::updatePriorityText()
@@ -141,7 +141,7 @@ namespace kt
}
updatePriorityText();
- tqparent->childStateChange();
+ parent->childStateChange();
}
int FileTreeItem::compare(TQListViewItem* i, int col, bool ascending) const
diff --git a/libktorrent/interfaces/plugin.cpp b/libktorrent/interfaces/plugin.cpp
index 50903d7..92a4f22 100644
--- a/libktorrent/interfaces/plugin.cpp
+++ b/libktorrent/interfaces/plugin.cpp
@@ -22,11 +22,11 @@
namespace kt
{
- Plugin::Plugin(TQObject *tqparent, const char* qt_name,const TQStringList & /*args*/,
+ Plugin::Plugin(TQObject *parent, const char* qt_name,const TQStringList & /*args*/,
const TQString & name,const TQString & gui_name,const TQString & author,
const TQString & email,const TQString & description,
const TQString & icon)
- : KParts::Plugin(tqparent,qt_name),
+ : KParts::Plugin(parent,qt_name),
name(name),author(author),email(email),description(description),icon(icon),gui_name(gui_name)
{
core = 0;
diff --git a/libktorrent/interfaces/plugin.h b/libktorrent/interfaces/plugin.h
index d147d46..9c72a0f 100644
--- a/libktorrent/interfaces/plugin.h
+++ b/libktorrent/interfaces/plugin.h
@@ -60,7 +60,7 @@ namespace kt
* @param description What does the plugin do
* @param icon Name of the plugin's icon
*/
- Plugin(TQObject *tqparent,const char* qt_name,const TQStringList & args,
+ Plugin(TQObject *parent,const char* qt_name,const TQStringList & args,
const TQString & name,const TQString & gui_name,const TQString & author,
const TQString & email,const TQString & description,
const TQString & icon);
diff --git a/libktorrent/interfaces/filetreeitem.h b/libktorrent/interfaces/filetreeitem.h
index 6d6ed79..9d32253 100644
--- a/libktorrent/interfaces/filetreeitem.h
+++ b/libktorrent/interfaces/filetreeitem.h
@@ -45,11 +45,11 @@ namespace kt
protected:
TQString name;
TorrentFileInterface & file;
- FileTreeDirItem* tqparent;
+ FileTreeDirItem* parent;
bool manual_change;
public:
/**
* Constructor, set the tqparent, name and file
* @param item Parent item
* @param name Name of file
* @param file THe TorrentFileInterface
@@ -45,11 +45,11 @@ namespace kt
public:
/**
- * Constructor, set the tqparent, name and file
+ * Constructor, set the parent, name and file
* @param item Parent item
* @param name Name of file
diff --git a/libktorrent/interfaces/prefpageinterface.h b/libktorrent/interfaces/prefpageinterface.h
index b27390e..850a344 100644
--- a/libktorrent/interfaces/prefpageinterface.h
+++ b/libktorrent/interfaces/prefpageinterface.h
@@ -58,9 +58,9 @@ namespace kt
/**
* Create the actual widget.
* @param tqparent The tqparent of the widget
*/
- virtual void createWidget(TQWidget* tqparent)=0;
+ virtual void createWidget(TQWidget* parent)=0;
/**
* Update all data on the widget, gets called before
@@ -58,9 +58,9 @@ namespace kt
/**
* Create the actual widget.
- * @param tqparent The tqparent of the widget
+ * @param parent The parent of the widget
*/